package edu.colorado.profileviewer;

import java.io.IOException;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.FileNotFoundException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;

import java.util.Iterator;
import java.util.Map;
import java.util.TreeMap;

import android.util.Log;

public class ProfileList implements Iterable<String> {

	private Map<String,ProfileData> profiles;

	public ProfileList() {
		profiles = new TreeMap<String,ProfileData>();
	}

	public void addUser(String name) {
		profiles.put(name, new ProfileData());
	}

	public void addUser(String name, ProfileData data) {
		profiles.put(name, data);
	}

	public void clear() {
		profiles.clear();
	}

	public boolean containsUser(String name) {
		return profiles.keySet().contains(name);
	}
	
	public void removeUser(String name) {
		profiles.remove(name);
	}

	public ProfileData getUser(String name) {
		return profiles.get(name);
	}

	public Iterator<String> iterator() {
		return profiles.keySet().iterator();
	}

	public void save(File f) {
		try {
			ObjectOutputStream output =
				new ObjectOutputStream(
						new FileOutputStream(f));

			output.writeObject(profiles);
			
			output.close();

			Log.i("Profile Viewer", "Profiles saved to " + f);

		} catch (FileNotFoundException ex) {
			Log.i("Profile Viewer", "Error: File Can Not Be Created: " + f);
			Log.i("Profile Viewer", "Attempt to save profiles aborted.");
		} catch (IOException ex) {
			Log.i("Profile Viewer", "Fatal error while saving profiles.");
			Log.i("Profile Viewer", "Attempt to save profiles aborted.");
		}
	}

	@SuppressWarnings("unchecked")
	public void load(File f) {
		try {
			ObjectInputStream input =
				new ObjectInputStream(
						new FileInputStream(f));

			profiles = (TreeMap<String,ProfileData>) input.readObject();
			
			input.close();

			Log.i("Profile Viewer", "Profiles loaded from " + f);

		} catch (FileNotFoundException ex) {
			Log.i("Profile Viewer", "File Not Found: " + f);
			Log.i("Profile Viewer", "Creating an empty set of profiles.");
			profiles.clear();
		} catch (IOException ex) {
			Log.i("Profile Viewer", "Fatal error while loading profiles.");
			Log.i("Profile Viewer", "Creating an empty set of profiles.");
			profiles.clear();
		} catch (ClassNotFoundException ex) {
			Log.i("Profile Viewer", "Fatal error while loading profiles.");
			Log.i("Profile Viewer", "Creating an empty set of profiles.");
			profiles.clear();
		}
	}
	
}
