package edu.colorado.profileviewer;

import android.app.ListFragment;
import android.content.Intent;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.widget.ArrayAdapter;
import android.widget.ListView;
import android.widget.TextView;

import java.io.File;

public class ProfileListFragment extends ListFragment {
	
    private ProfileList profiles = new ProfileList();
    private int itemSelected = -1; 

    public void onResume() {
		super.onResume();
		setListAdapter(getCurrentUsers());
    }

    public void onPause() {
    		super.onPause();
    		profiles.save(new File(getActivity().getFilesDir(), "profiles.bin"));
    }
    
	public void onCreate (Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setHasOptionsMenu(true);
	}
	
	public void onCreateOptionsMenu(Menu menu, MenuInflater inflater) {
		inflater.inflate(R.menu.fragment_profile_list, menu);
	}
	
	public void onPrepareOptionsMenu(Menu menu) {
		super.onPrepareOptionsMenu(menu);
	    MenuItem delete = menu.findItem(R.id.menu_delete_profile);
	    MenuItem edit = menu.findItem(R.id.menu_edit_profile);
		if (itemSelected != -1) {
			delete.setEnabled(true);
			edit.setEnabled(true);
		} else {
			delete.setEnabled(false);
			edit.setEnabled(false);			
		}
	}
	
	public boolean onOptionsItemSelected (MenuItem item) {
        Intent intent = new Intent(getActivity(), EditProfile.class);
		if (item.getItemId() == R.id.menu_new_profile) {
	        getActivity().startActivity(intent);			
		}
		if (item.getItemId() == R.id.menu_edit_profile) {
			TextView text = (TextView) getListView().getChildAt(itemSelected);
			intent.putExtra("name", text.getText().toString());
	        getActivity().startActivity(intent);
	        itemSelected = -1;
    			getActivity().invalidateOptionsMenu();
		}
		if (item.getItemId() == R.id.menu_delete_profile) {
			TextView text = (TextView) getListView().getChildAt(itemSelected);
			remove_name(text.getText().toString());
		}
		return true;
	}
	
    public void onListItemClick(ListView l, View v, int position, long id) {
    		itemSelected = position;
    		getActivity().invalidateOptionsMenu();
    }
	
	public void onActivityCreated(Bundle savedInstanceState) {
		super.onActivityCreated(savedInstanceState);
		setEmptyText("No Profiles.");
		setListAdapter(getCurrentUsers());
        getListView().setChoiceMode(ListView.CHOICE_MODE_SINGLE);

	}
	
	public void remove_name(String name) {
		profiles.removeUser(name);
		profiles.save(new File(getActivity().getFilesDir(), "profiles.bin"));
		setListAdapter(getCurrentUsers());
		itemSelected = -1;
		getActivity().invalidateOptionsMenu();
	}
	
    public ArrayAdapter<String> getCurrentUsers() {

        ArrayAdapter<String> adapter = new ArrayAdapter<String>(getActivity(), android.R.layout.simple_list_item_single_choice);

        profiles.clear();

        File appDir = getActivity().getFilesDir();

        profiles.load(new File(appDir, "profiles.bin"));

        for (String name : profiles) {
                adapter.add(name);
        }

        return adapter;

    }

}
