package edu.colorado.profileviewersql;

import android.os.Bundle;
import android.app.Activity;
import android.content.Intent;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.AdapterView;
import android.widget.AdapterView.OnItemClickListener;
import android.widget.ArrayAdapter;
import android.widget.ListView;
import android.widget.TextView;

public class Main extends Activity {

	private ListView profiles;
	private int itemSelected = -1;
	private ProfileDB profileDB = new ProfileDB(this);

	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_main);

		profiles = (ListView) findViewById(R.id.user_list);
		profiles.setAdapter(getCurrentUsers());
        profiles.setOnItemClickListener(new OnItemClickListener() {

            public void onItemClick(AdapterView<?> list, View list_item, int position, long id) {
            		Main.this.itemSelected = position;
            		Main.this.invalidateOptionsMenu();
            }
        });

	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		getMenuInflater().inflate(R.menu.activity_main, menu);
		return true;
	}

	public boolean onPrepareOptionsMenu(Menu menu) {
		super.onPrepareOptionsMenu(menu);
		MenuItem delete = menu.findItem(R.id.menu_delete_profile);
		MenuItem edit = menu.findItem(R.id.menu_edit_profile);
		if (itemSelected != -1) {
			delete.setEnabled(true);
			edit.setEnabled(true);
		} else {
			delete.setEnabled(false);
			edit.setEnabled(false);
		}
		return true;
	}

	public boolean onOptionsItemSelected (MenuItem item) {
		Intent intent = new Intent(this, EditProfile.class);
		if (item.getItemId() == R.id.menu_new_profile) {
			startActivity(intent);
		}
		if (item.getItemId() == R.id.menu_edit_profile) {
			TextView text = (TextView) profiles.getChildAt(itemSelected);
			intent.putExtra("name", text.getText().toString());
			startActivity(intent);
			itemSelected = -1;
			invalidateOptionsMenu();
		}
		if (item.getItemId() == R.id.menu_delete_profile) {
			TextView text = (TextView) profiles.getChildAt(itemSelected);
			remove_name(text.getText().toString());
		}
		return true;
	}
	
    public void onResume() {
        super.onResume();
		profiles.setAdapter(getCurrentUsers());
    }

	public ArrayAdapter<String> getCurrentUsers() {

		ArrayAdapter<String> adapter = new ArrayAdapter<String>(this, android.R.layout.simple_list_item_single_choice);

		SQLiteDatabase db = profileDB.getReadableDatabase();
		Cursor cursor = db.query("profiles", new String[] { "profile" }, null, null, null, null, "profile");
		while (cursor.moveToNext()) {
			adapter.add(cursor.getString(0));
			System.out.println("Got profile: " + cursor.getString(0));
		}
		cursor.close();
		
		if (adapter.getCount() == 0) {
			adapter.add("No Profiles.");			
			profiles.setChoiceMode(ListView.CHOICE_MODE_NONE);
		} else {
			profiles.setChoiceMode(ListView.CHOICE_MODE_SINGLE);
		}

		return adapter;
	}

	public void remove_name(String name) {
        SQLiteDatabase db = profileDB.getWritableDatabase();
        db.delete("profiles", "profile = ?", new String[] { name });

		profiles.setAdapter(getCurrentUsers());
        itemSelected = -1;
        invalidateOptionsMenu();

	}

}
