package edu.colorado.simplepaint;

import java.util.LinkedList;
import java.util.List;

import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.Rect;
import android.util.AttributeSet;
import android.view.MotionEvent;
import android.view.View;

public class PaintView extends View {

	private List<Rectangle> rects = new LinkedList<Rectangle>();
	private Paint current;
	private Paint background;
	private Rect  motionRect;

	public PaintView(Context context) {
		super(context);
		setFocusable(true);
		setFocusableInTouchMode(true);
		background = new Paint();
		background.setARGB(255, 255, 255, 255);

		current = new Paint();
	}

	public PaintView(Context context, AttributeSet atts) {
		super(context, atts);
		setFocusable(true);
		setFocusableInTouchMode(true);
		background = new Paint();
		background.setARGB(255, 255, 255, 255);

		current = new Paint();
	}

	protected void onDraw(Canvas canvas) {
		canvas.drawRect(0, 0, getWidth(), getHeight(), background);
		for (Rectangle r : rects) {
			canvas.drawRect(r.r, r.paint);
		}
		if (motionRect != null && motionRect.bottom > 0 && motionRect.right > 0) {
			canvas.drawRect(motionRect, current);
		}
	}

	public void setCurrentPaint(Paint p) {
		current = p;
	}

	public boolean onTouchEvent(MotionEvent event) {
		if (event.getAction() == MotionEvent.ACTION_DOWN){

			motionRect = new Rect();
			motionRect.top  = (int) event.getY();
			motionRect.left = (int) event.getX();

		} else if (event.getAction() == MotionEvent.ACTION_MOVE){

			motionRect.bottom  = (int) event.getY();
			motionRect.right = (int) event.getX();
			invalidate();

		} else if (event.getAction() == MotionEvent.ACTION_UP){

			motionRect.bottom  = (int) event.getY();
			motionRect.right = (int) event.getX();
			rects.add(new Rectangle(motionRect, new Paint(current)));
			motionRect = null;
			invalidate();

		}

		return true;
	}


}
